import autoscaling = require('@aws-cdk/aws-applicationautoscaling');
import { IQueue } from '@aws-cdk/aws-sqs';
import cdk = require('@aws-cdk/cdk');
import { BaseService } from './base/base-service';
import { ICluster } from './cluster';
import { ContainerImage } from './container-image';
import { LogDriver } from './log-drivers/log-driver';
/**
 * Properties to define a Query Worker service
 */
export interface QueueWorkerServiceBaseProps {
    /**
     * Cluster where service will be deployed
     */
    readonly cluster: ICluster;
    /**
     * The image to start.
     */
    readonly image: ContainerImage;
    /**
     * The CMD value to pass to the container. A string with commands delimited by commas.
     *
     * @default none
     */
    readonly command?: string[];
    /**
     * Number of desired copies of running tasks
     *
     * @default 1
     */
    readonly desiredTaskCount?: number;
    /**
     * Flag to indicate whether to enable logging
     *
     * @default true
     */
    readonly enableLogging?: boolean;
    /**
     * The environment variables to pass to the container.
     *
     * @default 'QUEUE_NAME: queue.queueName'
     */
    readonly environment?: {
        [key: string]: string;
    };
    /**
     * A queue for which to process items from.
     *
     * If specified and this is a FIFO queue, the queue name must end in the string '.fifo'.
     * @see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_CreateQueue.html
     *
     * @default 'SQSQueue with CloudFormation-generated name'
     */
    readonly queue?: IQueue;
    /**
     * Maximum capacity to scale to.
     *
     * @default (desiredTaskCount * 2)
     */
    readonly maxScalingCapacity?: number;
    /**
     * The intervals for scaling based on the SQS queue's ApproximateNumberOfMessagesVisible metric.
     *
     * Maps a range of metric values to a particular scaling behavior.
     * https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-scaling-simple-step.html
     *
     * @default [{ upper: 0, change: -1 },{ lower: 100, change: +1 },{ lower: 500, change: +5 }]
     */
    readonly scalingSteps?: autoscaling.ScalingInterval[];
}
/**
 * Base class for a Fargate and ECS queue worker service
 */
export declare abstract class QueueWorkerServiceBase extends cdk.Construct {
    /**
     * The SQS queue that the worker service will process from
     */
    readonly sqsQueue: IQueue;
    /**
     * Environment variables that will include the queue name
     */
    readonly environment: {
        [key: string]: string;
    };
    /**
     * The minimum number of tasks to run
     */
    readonly desiredCount: number;
    /**
     * The maximum number of instances for autoscaling to scale up to
     */
    readonly maxCapacity: number;
    /**
     * The scaling interval for autoscaling based off an SQS Queue size
     */
    readonly scalingSteps: autoscaling.ScalingInterval[];
    /**
     * The AwsLogDriver to use for logging if logging is enabled.
     */
    readonly logDriver?: LogDriver;
    constructor(scope: cdk.Construct, id: string, props: QueueWorkerServiceBaseProps);
    /**
     * Configure autoscaling based off of CPU utilization as well as the number of messages visible in the SQS queue
     *
     * @param service the ECS/Fargate service for which to apply the autoscaling rules to
     */
    protected configureAutoscalingForService(service: BaseService): void;
    /**
     * Create an AWS Log Driver with the provided streamPrefix
     *
     * @param prefix the Cloudwatch logging prefix
     */
    private createAwsLogDriver;
}
